@@ -3,8 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0303';
+our $VERSION = '0.0304';
 
+use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
 use Music::Scales qw(get_scale_notes);
@@ -115,6 +116,9 @@ has verbose => (
 sub generate {
     my ($self) = @_;
 
+    croak 'chords length must equal number of net keys'
+        unless @{ $self->chords } == keys %{ $self->net };
+
     # Build the graph
     for my $posn (keys %{ $self->net }) {
         for my $p (@{ $self->net->{$posn} }) {
@@ -280,7 +284,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0303
+version 0.0304
 
 =head1 SYNOPSIS
 
